# sxscatalog

[![PyPI - Version](https://img.shields.io/pypi/v/sxscatalog.svg)](https://pypi.org/project/sxscatalog)


This package is a minimal set of tools for interacting with the SXS
Collaboration's catalog of numerical-relativity simulations.  It is
intended to be used by other packages, such as
[`sxs`](https://github.com/sxs-collaboration/sxs/).  It only needs to
exist separately for simple applications like [the web
interface](https://sxs-collaboration.github.io/sxscatalog/); users will most
likely never need this package directly.
